@@ -4,23 +4,21 @@ import torch
 from torch.optim.optimizer import Optimizer
 
 from pytorch_optimizer.base.base_optimizer import BaseOptimizer
+from pytorch_optimizer.base.exception import NoSparseGradientError
 from pytorch_optimizer.base.types import BETAS, CLOSURE, DEFAULTS, LOSS, PARAMETERS
 
 
 class AdaPNM(Optimizer, BaseOptimizer):
-    """
-    Reference : https://github.com/zeke-xie/Positive-Negative-Momentum
-    Example :
-        from pytorch_optimizer import AdaPNM
-        ...
-        model = YourModel()
-        optimizer = AdaPNM(model.parameters())
-        ...
-        for input, output in data:
-          optimizer.zero_grad()
-          loss = loss_function(output, model(input))
-          loss.backward()
-          optimizer.step()
+    r"""Adam + Positive-Negative Momentum Optimizers
+
+    :param params: PARAMETERS. iterable of parameters to optimize or dicts defining parameter groups.
+    :param lr: float. learning rate.
+    :param betas: BETAS. coefficients used for computing running averages of gradient and the squared hessian trace.
+    :param weight_decay: float. weight decay (L2 penalty).
+    :param weight_decouple: bool. use weight_decouple.
+    :param amsgrad: bool. whether to use the AMSGrad variant of this algorithm from the paper.
+    :param adamd_debias_term: bool. Only correct the denominator to avoid inflating step sizes early in training.
+    :param eps: float. term added to the denominator to improve numerical stability.
     """
 
     def __init__(
@@ -31,28 +29,27 @@ class AdaPNM(Optimizer, BaseOptimizer):
         weight_decay: float = 0.0,
         weight_decouple: bool = True,
         amsgrad: bool = True,
+        adamd_debias_term: bool = False,
         eps: float = 1e-8,
     ):
-        """AdaPNM optimizer
-        :param params: PARAMETERS. iterable of parameters to optimize or dicts defining parameter groups
-        :param lr: float. learning rate
-        :param betas: BETAS. coefficients used for computing running averages of gradient and the squared hessian trace
-        :param weight_decay: float. weight decay (L2 penalty)
-        :param weight_decouple: bool. use weight_decouple
-        :param amsgrad: bool. whether to use the AMSGrad variant of this algorithm from the paper
-        :param eps: float. term added to the denominator to improve numerical stability
-        """
         self.lr = lr
         self.betas = betas
         self.weight_decay = weight_decay
         self.weight_decouple = weight_decouple
         self.amsgrad = amsgrad
+        self.adamd_debias_term = adamd_debias_term
         self.eps = eps
 
         self.validate_parameters()
 
         defaults: DEFAULTS = dict(
-            lr=lr, betas=betas, weight_decay=weight_decay, weight_decouple=weight_decouple, amsgrad=amsgrad, eps=eps
+            lr=lr,
+            betas=betas,
+            weight_decay=weight_decay,
+            weight_decouple=weight_decouple,
+            amsgrad=amsgrad,
+            adamd_debias_term=adamd_debias_term,
+            eps=eps,
         )
         super().__init__(params, defaults)
 
@@ -62,6 +59,10 @@ class AdaPNM(Optimizer, BaseOptimizer):
         self.validate_weight_decay(self.weight_decay)
         self.validate_epsilon(self.eps)
 
+    @property
+    def __name__(self) -> str:
+        return 'AdaPNM'
+
     @torch.no_grad()
     def reset(self):
         for group in self.param_groups:
@@ -72,7 +73,6 @@ class AdaPNM(Optimizer, BaseOptimizer):
                 state['exp_avg'] = torch.zeros_like(p)
                 state['exp_avg_sq'] = torch.zeros_like(p)
                 state['neg_exp_avg'] = torch.zeros_like(p)
-
                 if group['amsgrad']:
                     state['max_exp_avg_sq'] = torch.zeros_like(p)
 
@@ -90,7 +90,7 @@ class AdaPNM(Optimizer, BaseOptimizer):
 
                 grad = p.grad
                 if grad.is_sparse:
-                    raise RuntimeError('AdaPNM does not support sparse gradients')
+                    raise NoSparseGradientError(self.__name__)
 
                 if group['weight_decouple']:
                     p.mul_(1.0 - group['lr'] * group['weight_decay'])
@@ -103,7 +103,6 @@ class AdaPNM(Optimizer, BaseOptimizer):
                     state['exp_avg'] = torch.zeros_like(p)
                     state['exp_avg_sq'] = torch.zeros_like(p)
                     state['neg_exp_avg'] = torch.zeros_like(p)
-
                     if group['amsgrad']:
                         state['max_exp_avg_sq'] = torch.zeros_like(p)
 
@@ -127,7 +126,9 @@ class AdaPNM(Optimizer, BaseOptimizer):
 
                 denom = (exp_avg_sq.sqrt() / math.sqrt(bias_correction2)).add_(group['eps'])
 
-                step_size = group['lr'] / bias_correction1
+                step_size = group['lr']
+                if not group['adamd_debias_term']:
+                    step_size /= bias_correction1
 
                 noise_norm = math.sqrt((1 + beta3) ** 2 + beta3 ** 2)  # fmt: skip
                 pn_momentum = exp_avg.mul(1 + beta3).add(neg_exp_avg, alpha=-beta3).mul(1.0 / noise_norm)
