@@ -5,10 +5,11 @@ from pytorch_optimizer.optimizer.utils import unit_norm
 
 def agc(p: torch.Tensor, agc_eps: float, agc_clip_val: float, eps: float = 1e-6) -> torch.Tensor:
     """Clip gradient values in excess of the unit wise norm
-    :param p: parameter. parameter
-    :param agc_eps: float. epsilon
-    :param agc_clip_val: float. norm clip
-    :param eps: float. simple stop from div by zero and no relation to standard optimizer eps
+
+    :param p: parameter. model parameter.
+    :param agc_eps: float. epsilon.
+    :param agc_clip_val: float. norm clip.
+    :param eps: float. simple stop from div by zero and no relation to standard optimizer eps.
     """
     p_norm = unit_norm(p).clamp_(agc_eps)
     g_norm = unit_norm(p.grad)
