@@ -4,23 +4,19 @@ import torch
 from torch.optim.optimizer import Optimizer
 
 from pytorch_optimizer.base.base_optimizer import BaseOptimizer
+from pytorch_optimizer.base.exception import NoSparseGradientError
 from pytorch_optimizer.base.types import BETAS, CLOSURE, DEFAULTS, LOSS, PARAMETERS
 
 
 class PNM(Optimizer, BaseOptimizer):
-    """
-    Reference : https://github.com/zeke-xie/Positive-Negative-Momentum
-    Example :
-        from pytorch_optimizer import PNM
-        ...
-        model = YourModel()
-        optimizer = PNM(model.parameters())
-        ...
-        for input, output in data:
-          optimizer.zero_grad()
-          loss = loss_function(output, model(input))
-          loss.backward()
-          optimizer.step()
+    r"""Positive-Negative Momentum Optimizers
+
+    :param params: PARAMETERS. iterable of parameters to optimize or dicts defining parameter groups.
+    :param lr: float. learning rate.
+    :param betas: BETAS. coefficients used for computing running averages of gradient and the squared hessian trace.
+    :param weight_decay: float. weight decay (L2 penalty).
+    :param weight_decouple: bool. use weight_decouple.
+    :param eps: float. term added to the denominator to improve numerical stability.
     """
 
     def __init__(
@@ -32,14 +28,6 @@ class PNM(Optimizer, BaseOptimizer):
         weight_decouple: bool = True,
         eps: float = 1e-8,
     ):
-        """PNM optimizer
-        :param params: PARAMETERS. iterable of parameters to optimize or dicts defining parameter groups
-        :param lr: float. learning rate
-        :param betas: BETAS. coefficients used for computing running averages of gradient and the squared hessian trace
-        :param weight_decay: float. weight decay (L2 penalty)
-        :param weight_decouple: bool. use weight_decouple
-        :param eps: float. term added to the denominator to improve numerical stability
-        """
         self.lr = lr
         self.betas = betas
         self.weight_decay = weight_decay
@@ -62,6 +50,10 @@ class PNM(Optimizer, BaseOptimizer):
         self.validate_weight_decay(self.weight_decay)
         self.validate_epsilon(self.eps)
 
+    @property
+    def __name__(self) -> str:
+        return 'PNM'
+
     @torch.no_grad()
     def reset(self):
         for group in self.param_groups:
@@ -86,7 +78,7 @@ class PNM(Optimizer, BaseOptimizer):
 
                 grad = p.grad
                 if grad.is_sparse:
-                    raise RuntimeError('PNM does not support sparse gradients')
+                    raise NoSparseGradientError(self.__name__)
 
                 if group['weight_decouple']:
                     p.mul_(1.0 - group['lr'] * group['weight_decay'])
